
(function (Drupal, once) {

  "use strict";

  /**
   * React on radio button changes and set the value of the actual menu parent element.
   */
  const change = () => {
    const triggers = Array.from(document.querySelectorAll('.menu-tree button, .menu-tree li'));
    window.addEventListener('click', ev => {
      let elm = ev.target;
      if (elm.tagName === 'LI') {
        elm = elm.querySelector('button:not([disabled])');
      }
      if (triggers.includes(elm)) {
        ev.preventDefault();
        const target = document.querySelector('input[name="menu[menu_parent]"]');
        target.value = elm.getAttribute('data-value');
        triggers.forEach(elm => {
          elm.classList.remove('selected');
          elm.parentElement.classList.remove('selected');
        });
        elm.classList.add('selected');
        elm.parentElement.classList.add('selected');
      }
    }, false);
  }

  /**
   * Set the default value of the menu tree and expand active branches.
   */
  const initalState = () => {
    const parent = document.querySelector('input[name="menu[menu_parent]"]');
    let elem = document.querySelector('button[data-value="' + parent.value + '"]');
    if (elem) {
      elem.classList.add('selected');
      elem.parentElement.classList.add('selected');
    }
    while (elem) {
      if (elem.matches('details')) {
        elem.setAttribute('open', 'open');
      }
      elem = elem.parentElement;
    }
  }

  /**
   * Attach event listeners and set the initial state of the menu.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.menuTree = {
    attach: function (context, settings) {
      once('menu-tree', 'body', context).forEach(elm => {
        initalState();
        change();
      });
    }
  };

})(Drupal, once);
